@@ -1,6 +1,16 @@
 import curses
 from dataclasses import dataclass, field
-from typing import Generic, Callable, List, Optional, Dict, Union, Tuple, TypeVar
+from typing import (
+    Generic,
+    Callable,
+    List,
+    Optional,
+    Dict,
+    Union,
+    Tuple,
+    TypeVar,
+    Sequence,
+)
 
 __all__ = ["Picker", "pick"]
 
@@ -10,6 +20,9 @@ KEYS_UP = (curses.KEY_UP, ord("k"))
 KEYS_DOWN = (curses.KEY_DOWN, ord("j"))
 KEYS_SELECT = (curses.KEY_RIGHT, ord(" "))
 
+SYMBOL_CIRCLE_FILLED = "◉"
+SYMBOL_CIRCLE_EMPTY = "◯"
+
 CUSTOM_HANDLER_RETURN_T = TypeVar("CUSTOM_HANDLER_RETURN_T")
 KEY_T = int
 OPTIONS_MAP_VALUE_T = TypeVar("OPTIONS_MAP_VALUE_T")
@@ -18,24 +31,14 @@ PICK_RETURN_T = Tuple[OPTIONS_MAP_VALUE_T, int]
 
 @dataclass
 class Picker(Generic[CUSTOM_HANDLER_RETURN_T, OPTIONS_MAP_VALUE_T]):
-    """The :class:`Picker <Picker>` object
-
-    :param options: a list of options to choose from
-    :param title: (optional) a title above options list
-    :param multiselect: (optional) if true its possible to select multiple values by hitting SPACE, defaults to False
-    :param indicator: (optional) custom the selection indicator
-    :param default_index: (optional) set this if the default selected option is not the first one
-    :param options_map_func: (optional) a mapping function to pass each option through before displaying
-    """
-
-    options: List[OPTIONS_MAP_VALUE_T]
+    options: Sequence[OPTIONS_MAP_VALUE_T]
     title: Optional[str] = None
     indicator: str = "*"
     default_index: int = 0
     multiselect: bool = False
     min_selection_count: int = 0
     options_map_func: Callable[[OPTIONS_MAP_VALUE_T], Optional[str]] = str
-    all_selected: List[int] = field(init=False, default_factory=list)
+    selected_indexes: List[int] = field(init=False, default_factory=list)
     custom_handlers: Dict[KEY_T, Callable[["Picker"], CUSTOM_HANDLER_RETURN_T]] = field(
         init=False, default_factory=dict
     )
@@ -76,10 +79,10 @@ class Picker(Generic[CUSTOM_HANDLER_RETURN_T, OPTIONS_MAP_VALUE_T]):
 
     def mark_index(self) -> None:
         if self.multiselect:
-            if self.index in self.all_selected:
-                self.all_selected.remove(self.index)
+            if self.index in self.selected_indexes:
+                self.selected_indexes.remove(self.index)
             else:
-                self.all_selected.append(self.index)
+                self.selected_indexes.append(self.index)
 
     def get_selected(self) -> Union[List[PICK_RETURN_T], PICK_RETURN_T]:
         """return the current selected option as a tuple: (option, index)
@@ -87,7 +90,7 @@ class Picker(Generic[CUSTOM_HANDLER_RETURN_T, OPTIONS_MAP_VALUE_T]):
         """
         if self.multiselect:
             return_tuples = []
-            for selected in self.all_selected:
+            for selected in self.selected_indexes:
                 return_tuples.append((self.options[selected], selected))
             return return_tuples
         else:
@@ -98,30 +101,31 @@ class Picker(Generic[CUSTOM_HANDLER_RETURN_T, OPTIONS_MAP_VALUE_T]):
             return self.title.split("\n") + [""]
         return []
 
-    def get_option_lines(self) -> Union[List[str], List[Tuple[str, int]]]:
-        lines: Union[List[str], List[Tuple[str, int]]] = []  # type: ignore[assignment]
+    def get_option_lines(self) -> List[str]:
+        lines: List[str] = []
         for index, option in enumerate(self.options):
-            option_as_str = self.options_map_func(option)
-
             if index == self.index:
                 prefix = self.indicator
             else:
                 prefix = len(self.indicator) * " "
 
-            line: Union[Tuple[str, int], str]
-            if self.multiselect and index in self.all_selected:
-                format = curses.color_pair(1)
-                line = ("{0} {1}".format(prefix, option_as_str), format)
-            else:
-                line = "{0} {1}".format(prefix, option_as_str)
-            lines.append(line)  # type: ignore[arg-type]
+            if self.multiselect:
+                symbol = (
+                    SYMBOL_CIRCLE_FILLED
+                    if index in self.selected_indexes
+                    else SYMBOL_CIRCLE_EMPTY
+                )
+                prefix = f"{prefix} {symbol} "
+
+            option_as_str = self.options_map_func(option)
+            lines.append(f"{prefix} {option_as_str}")
 
         return lines
 
     def get_lines(self) -> Tuple[List, int]:
         title_lines = self.get_title_lines()
         option_lines = self.get_option_lines()
-        lines = title_lines + option_lines  # type: ignore[operator]
+        lines = title_lines + option_lines
         current_line = self.index + len(title_lines) + 1
         return lines, current_line
 
@@ -144,10 +148,7 @@ class Picker(Generic[CUSTOM_HANDLER_RETURN_T, OPTIONS_MAP_VALUE_T]):
         lines_to_draw = lines[self.scroll_top : self.scroll_top + max_rows]
 
         for line in lines_to_draw:
-            if type(line) is tuple:
-                screen.addnstr(y, x, line[0], max_x - 2, line[1])
-            else:
-                screen.addnstr(y, x, line, max_x - 2)
+            screen.addnstr(y, x, line, max_x - 2)
             y += 1
 
         screen.refresh()
@@ -165,7 +166,7 @@ class Picker(Generic[CUSTOM_HANDLER_RETURN_T, OPTIONS_MAP_VALUE_T]):
             elif c in KEYS_ENTER:
                 if (
                     self.multiselect
-                    and len(self.all_selected) < self.min_selection_count
+                    and len(self.selected_indexes) < self.min_selection_count
                 ):
                     continue
                 return self.get_selected()
@@ -182,9 +183,6 @@ class Picker(Generic[CUSTOM_HANDLER_RETURN_T, OPTIONS_MAP_VALUE_T]):
             curses.use_default_colors()
             # hide the cursor
             curses.curs_set(0)
-            # add some color for multi_select
-            # @todo make colors configurable
-            curses.init_pair(1, curses.COLOR_GREEN, curses.COLOR_WHITE)
         except:
             # Curses failed to initialize color support, eg. when TERM=vt100
             curses.initscr()
@@ -202,7 +200,7 @@ class Picker(Generic[CUSTOM_HANDLER_RETURN_T, OPTIONS_MAP_VALUE_T]):
 
 
 def pick(
-    options: List[OPTIONS_MAP_VALUE_T],
+    options: Sequence[OPTIONS_MAP_VALUE_T],
     title: Optional[str] = None,
     indicator: str = "*",
     default_index: int = 0,
@@ -210,16 +208,7 @@ def pick(
     min_selection_count: int = 0,
     options_map_func: Callable[[OPTIONS_MAP_VALUE_T], Optional[str]] = str,
 ) -> Union[List[PICK_RETURN_T], PICK_RETURN_T]:
-    """Construct and start a :class:`Picker <Picker>`.
-
-    Usage::
-
-      >>> from pick import pick
-      >>> title = 'Please choose an option: '
-      >>> options = ['option1', 'option2', 'option3']
-      >>> option, index = pick(options, title)
-    """
-    picker = Picker(
+    picker: Picker = Picker(
         options,
         title,
         indicator,
